Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.xiph.org/xiph/opus.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJean-Marc Valin <jmvalin@jmvalin.ca>2011-10-22 07:21:34 +0400
committerJean-Marc Valin <jmvalin@jmvalin.ca>2011-10-22 07:21:34 +0400
commit3b2aee062d08fc72f12a4379ce2d6e2b444d5021 (patch)
tree5e470d24cb1f00a2e764823fd404220f55b0ff80 /silk/main.h
parente53ebd696a34e2a74b1ccb5132a946b7c965f448 (diff)
Implements glitchless switching between SILK bandwidths
Only encoder changes were necessary because this uses the same "redundant frames" mechanism as SILK<->CELT switching. This also fixes a regression introduced in 78291b27 that was causing the encoder to go back and forth between bandwidths when SILK wasn't ready to change.
Diffstat (limited to 'silk/main.h')
-rw-r--r--silk/main.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/silk/main.h b/silk/main.h
index 1f2f01a7..f5238136 100644
--- a/silk/main.h
+++ b/silk/main.h
@@ -138,7 +138,8 @@ opus_int check_control_input(
/* Control internal sampling rate */
opus_int silk_control_audio_bandwidth(
- silk_encoder_state *psEncC /* I/O Pointer to Silk encoder state */
+ silk_encoder_state *psEncC, /* I/O Pointer to Silk encoder state */
+ silk_EncControlStruct *encControl /* I: Control structure */
);
/* Control SNR of redidual quantizer */